/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.rm.datasource.undo.mysql;

import org.apache.seata.rm.datasource.sql.struct.Field;
import org.apache.seata.sqlparser.struct.ColumnMeta;
import org.apache.seata.sqlparser.struct.TableMeta;

import java.sql.Types;

/**
 * the type MySQLJsonHelper
 **/
public class MySQLJsonHelper {
    public static String convertIfJson(Field field, TableMeta tableMeta) {
        ColumnMeta columnMeta = tableMeta.getColumnMeta(field.getName());
        if (columnMeta != null
                && columnMeta.getDataType() == Types.OTHER
                && "JSON".equals(columnMeta.getDataTypeName())) {
            return "CONVERT(? USING utf8mb4)";
        }
        return "?";
    }
}
